==> dekshell-0.2.26-py3-none-any.whl: dekshell/core/markers/var.py <==
import re
from .base import MarkerBase, MarkerWithEnd, MarkerNoTranslator, cmd_call_prefix_simple, cmd_call_prefix_chain
from .function import CallMarker
from .shell import TimeoutMarker, RetryMarker
from .invoke import MarkerInvokerBase, InvokeMarker, GotoMarker


class MarkerAssignBase(MarkerBase):
    tag_head_re = r"[^\W\d]\w*[ \t\f\r]*%s"


class MarkerAssignValueBase(MarkerAssignBase):
    def execute(self, context, command, marker_node, marker_set):
        command = command.lstrip()
        index = re.match(self.tag_head_re % '', command).span()[1]
        var_name = command[:index].rstrip()
        rest = command[index:]
        index = re.match(self.tag_head_re_args, rest).span()[1]
        return self.assign_value(context, marker_node, marker_set, var_name, rest[index:].strip())

    def assign_value(self, context, marker_node, marker_set, var_name, expression):
        self.set_var_raw(context, var_name, self.get_value(context, marker_node, marker_set, expression))

    def get_value(self, context, marker_node, marker_set, expression):
        pass


class IgnoreMarker(MarkerBase):
    tag_head = ':'


class AssignStrMarker(MarkerAssignValueBase):
    tag_head_re_args = ':'

    def get_value(self, context, marker_node, marker_set, expression):
        return expression


class AssignRawStrMarker(AssignStrMarker, MarkerNoTranslator):
    tag_head_re_args = re.escape(r'\:')


class AssignMultiLineStrMarker(MarkerAssignBase, MarkerWithEnd):
    tag_head_re_args = '::'

    def execute(self, context, command, marker_node, marker_set):
        text = self.get_inner_content(context, marker_node)
        args = self.split_raw(command, 1, self.tag_head_re_args)
        self.set_var(context, args, 0, text)
        return []


class AssignMultiLineRawStrMarker(AssignMultiLineStrMarker, MarkerNoTranslator):
    tag_head_re_args = re.escape(r'\::')


class AssignEvalMarker(MarkerAssignValueBase, MarkerNoTranslator):
    tag_head_re_args = '='

    def get_value(self, context, marker_node, marker_set, expression):
        return self.eval(context, expression)


class AssignTranslatorEvalMarker(MarkerAssignValueBase):
    tag_head_re_args = '=:'

    def get_value(self, context, marker_node, marker_set, expression):
        return self.eval(context, expression)


class AssignExecMarker(MarkerAssignBase, MarkerWithEnd, MarkerNoTranslator):
    tag_head_re_args = '=='

    def execute(self, context, command, marker_node, marker_set):
        code = self.get_inner_content(context, marker_node)
        result = self.eval_codes(context, code)
        args = self.split_raw(command, 1, self.tag_head_re_args)
        self.set_var(context, args, 0, result)
        return []


class AssignCmdcallMarker(MarkerAssignValueBase):
    tag_head_re_args_raw = cmd_call_prefix_simple
    tag_head_re_args = re.escape(tag_head_re_args_raw)

    def get_value(self, context, marker_node, marker_set, expression):
        return self.eval_mixin(context, self.tag_head_re_args_raw + expression, False)


class AssignCmdcallChainMarker(AssignCmdcallMarker):
    tag_head_re_args_raw = cmd_call_prefix_chain + cmd_call_prefix_simple
    tag_head_re_args = re.escape(tag_head_re_args_raw)


class AssignCallMarker(MarkerAssignValueBase, CallMarker):
    tag_head = None
    tag_head_re_args = r'call[ \t\f\r\n]+'

    def assign_value(self, context, marker_node, marker_set, var_name, expression):
        def callback(value):
            self.set_var_raw(context, var_name, self.real_return_value(value))

        return *self.execute_core(context, expression), callback


class AssignMarkerInvokerBase(MarkerAssignValueBase, MarkerInvokerBase):
    tag_head = None

    def assign_value(self, context, marker_node, marker_set, var_name, expression):
        self.set_var_raw(context, var_name, self.execute_core(context, marker_set, expression))


class AssignInvokerMarker(AssignMarkerInvokerBase, InvokeMarker):
    tag_head_re_args = r'invoke[ \t\f\r\n]+'


class AssignGotoMarker(AssignMarkerInvokerBase, GotoMarker):
    tag_head_re_args = r'goto[ \t\f\r\n]+'


class AssignTimeoutMarker(MarkerAssignValueBase, TimeoutMarker):
    tag_head = None
    tag_head_re_args = r'timeout[ \t\f\r\n]+'

    def get_value(self, context, marker_node, marker_set, expression):
        timeout, expression = self.split_raw(expression, 1)
        return self.execute_core_timeout(context, expression, marker_node, marker_set, timeout)


class AssignRetryMarker(MarkerAssignValueBase, RetryMarker):
    tag_head = None
    tag_head_re_args = r'retry[ \t\f\r\n]+'

    def get_value(self, context, marker_node, marker_set, expression):
        times, expression = self.split_raw(expression, 1)
        return self.execute_core_retry(context, expression, marker_node, marker_set, times)


class DelVarMarker(MarkerBase):
    tag_head = "del"

    def execute(self, context, command, marker_node, marker_set):
        name = self.split_raw(command, 1, self.tag_head)[-1]
        if name:
            context.remove_variable(name)

==> dekshell-0.2.27-py3-none-any.whl: dekshell/core/markers/var.py <==
import re
from .base import MarkerBase, MarkerWithEnd, MarkerNoTranslator, cmd_call_prefix_simple, cmd_call_prefix_chain
from .function import CallMarker
from .shell import TimeoutMarker, RetryMarker
from .invoke import MarkerInvokerBase, InvokeMarker, GotoMarker


class MarkerAssignBase(MarkerBase):
    tag_head_re = r"[^\W\d]\w*[ \t\f\r]*%s"


class MarkerAssignValueBase(MarkerAssignBase):
    def execute(self, context, command, marker_node, marker_set):
        command = command.lstrip()
        index = re.match(self.tag_head_re % '', command).span()[1]
        var_name = command[:index].rstrip()
        rest = command[index:]
        index = re.match(self.tag_head_re_args, rest).span()[1]
        return self.assign_value(context, marker_node, marker_set, var_name, rest[index:].strip())

    def assign_value(self, context, marker_node, marker_set, var_name, expression):
        self.set_var_raw(context, var_name, self.get_value(context, marker_node, marker_set, expression))

    def get_value(self, context, marker_node, marker_set, expression):
        pass


class IgnoreMarker(MarkerBase):
    tag_head = ':'


class AssignStrMarker(MarkerAssignValueBase):
    tag_head_re_args = ':'

    def get_value(self, context, marker_node, marker_set, expression):
        return expression


class AssignRawStrMarker(AssignStrMarker, MarkerNoTranslator):
    tag_head_re_args = re.escape(r'\:')


class AssignMultiLineStrMarker(MarkerAssignBase, MarkerWithEnd):
    tag_head_re_args = '::'
    _translate_type = None

    def execute(self, context, command, marker_node, marker_set):
        text = self.get_inner_content(context, marker_node, translate=self._translate_type)
        var_name = command[:re.search(self.tag_head_re_args, command).span()[0]]
        self.set_var_raw(context, var_name.strip(), text)
        return []


class AssignMultiLineRawStrMarker(AssignMultiLineStrMarker, MarkerNoTranslator):
    tag_head_re_args = re.escape(r'\::')
    _translate_type = False


class AssignEvalMarker(MarkerAssignValueBase, MarkerNoTranslator):
    tag_head_re_args = '='

    def get_value(self, context, marker_node, marker_set, expression):
        return self.eval(context, expression)


class AssignTranslatorEvalMarker(MarkerAssignValueBase):
    tag_head_re_args = '=:'

    def get_value(self, context, marker_node, marker_set, expression):
        return self.eval(context, expression)


class AssignExecMarker(MarkerAssignBase, MarkerWithEnd, MarkerNoTranslator):
    tag_head_re_args = '=='

    def execute(self, context, command, marker_node, marker_set):
        code = self.get_inner_content(context, marker_node)
        result = self.eval_codes(context, code)
        args = self.split_raw(command, 1, self.tag_head_re_args)
        self.set_var(context, args, 0, result)
        return []


class AssignCmdcallMarker(MarkerAssignValueBase):
    tag_head_re_args_raw = cmd_call_prefix_simple
    tag_head_re_args = re.escape(tag_head_re_args_raw)

    def get_value(self, context, marker_node, marker_set, expression):
        return self.eval_mixin(context, self.tag_head_re_args_raw + expression, False)


class AssignCmdcallChainMarker(AssignCmdcallMarker):
    tag_head_re_args_raw = cmd_call_prefix_chain + cmd_call_prefix_simple
    tag_head_re_args = re.escape(tag_head_re_args_raw)


class AssignCallMarker(MarkerAssignValueBase, CallMarker):
    tag_head = None
    tag_head_re_args = r'call[ \t\f\r\n]+'

    def assign_value(self, context, marker_node, marker_set, var_name, expression):
        def callback(value):
            self.set_var_raw(context, var_name, self.real_return_value(value))

        return *self.execute_core(context, expression), callback


class AssignMarkerInvokerBase(MarkerAssignValueBase, MarkerInvokerBase):
    tag_head = None

    def assign_value(self, context, marker_node, marker_set, var_name, expression):
        self.set_var_raw(context, var_name, self.execute_core(context, marker_set, expression))


class AssignInvokerMarker(AssignMarkerInvokerBase, InvokeMarker):
    tag_head_re_args = r'invoke[ \t\f\r\n]+'


class AssignGotoMarker(AssignMarkerInvokerBase, GotoMarker):
    tag_head_re_args = r'goto[ \t\f\r\n]+'


class AssignTimeoutMarker(MarkerAssignValueBase, TimeoutMarker):
    tag_head = None
    tag_head_re_args = r'timeout[ \t\f\r\n]+'

    def get_value(self, context, marker_node, marker_set, expression):
        timeout, expression = self.split_raw(expression, 1)
        return self.execute_core_timeout(context, expression, marker_node, marker_set, timeout)


class AssignRetryMarker(MarkerAssignValueBase, RetryMarker):
    tag_head = None
    tag_head_re_args = r'retry[ \t\f\r\n]+'

    def get_value(self, context, marker_node, marker_set, expression):
        times, expression = self.split_raw(expression, 1)
        return self.execute_core_retry(context, expression, marker_node, marker_set, times)


class DelVarMarker(MarkerBase):
    tag_head = "del"

    def execute(self, context, command, marker_node, marker_set):
        name = self.split_raw(command, 1, self.tag_head)[-1]
        if name:
            context.remove_variable(name)
